==> igniteui-angular-charts-14.1.1.tgz: package/esm5/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.get_dd = function () {
        return true;
    };
    PolarAreaSeries.prototype.bx = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.lz = function (a) {
        _super.prototype.lz.call(this, a);
        this.vg = a;
    };
    PolarAreaSeries.prototype.ve = function (a) {
        var b = a;
        b.c5();
    };
    PolarAreaSeries.prototype.vf = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.c6(a.m, this.ft);
        this.r6.ax(this, this.st(), runOn(this, this.rj));
        var g = false;
        var h = this.r6.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            this.t1(-1, this.sf.count, b.q);
        }
        var i = f.dc;
        var j = f.db;
        this.r6.ad(i, true, false, true, true);
        this.r6.ad(j, false, true, false, false);
        j._opacity = this.r6.j * this.fq;
    };
    PolarAreaSeries.prototype.get_vb = function () {
        return true;
    };
    PolarAreaSeries.prototype.u6 = function () {
        return this.vh;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vh:vj', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.da = new Path();
        _this.c9 = new Path();
        _this.c8 = new Path();
        _this.c7 = new Path();
        _this.c4 = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c4.qd = Defaults.e;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "db", {
        get: function () {
            return this.c9;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PolarAreaSeriesView.prototype, "dc", {
        get: function () {
            return this.da;
        },
        enumerable: false,
        configurable: true
    });
    PolarAreaSeriesView.prototype.c5 = function () {
        this.c9.ak = null;
        this.da.ak = null;
        this.c7.ak = null;
        this.c8.ak = null;
        this.aq();
    };
    PolarAreaSeriesView.prototype.c6 = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.c4.u3.d(this.da, c, b);
        this.c4.u3.d(this.c9, c, b);
        this.aq();
    };
    PolarAreaSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    PolarAreaSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c8.ak = this.da.ak;
        this.c7.ak = this.c9.ak;
        this.c8._stroke = a;
        this.c8.ac = this.e.fu + 3;
        this.c7._fill = a;
        this.c7._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
                a.s(this.c8);
            }
            else {
                a.s(this.c9);
                a.s(this.da);
            }
        }
    };
    PolarAreaSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.da, "polarShape", ["Main"]);
        this.e.a8.exportPathData(a, this.c9, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pb = a;
        this.e.gw = 5;
        this.e.gx = 5;
        this.e.gy = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };

==> igniteui-angular-charts-14.2.0.tgz: package/esm5/lib/PolarAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep, Point_$type } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { List$1 } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var PolarAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeries, _super);
    function PolarAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarAreaSeries.$;
        return _this;
    }
    PolarAreaSeries.prototype.get_dd = function () {
        return true;
    };
    PolarAreaSeries.prototype.bx = function () {
        return new PolarAreaSeriesView(this);
    };
    PolarAreaSeries.prototype.l2 = function (a) {
        _super.prototype.l2.call(this, a);
        this.vk = a;
    };
    PolarAreaSeries.prototype.vi = function (a) {
        var b = a;
        b.c5();
    };
    PolarAreaSeries.prototype.vj = function (a, b) {
        if (a.m.count > 0) {
            var c = a.m._inner[0];
            var d = a.m._inner[a.m.count - 1];
            var e = c.x == d.x && c.y == d.y;
            if (!e) {
                a.m.add(a.m._inner[0]);
            }
        }
        var f = b;
        f.c6(a.m, this.fv);
        this.sa.ax(this, this.sx(), runOn(this, this.rn));
        var g = false;
        var h = this.sa.b;
        if (h != null) {
            g = true;
        }
        if (g) {
            this.t5(-1, this.sj.count, b.q);
        }
        var i = f.dc;
        var j = f.db;
        this.sa.ad(i, true, false, true, true);
        this.sa.ad(j, false, true, false, false);
        j._opacity = this.sa.j * this.fs;
    };
    PolarAreaSeries.prototype.get_vf = function () {
        return true;
    };
    PolarAreaSeries.prototype.va = function () {
        return this.vl;
    };
    PolarAreaSeries.$t = markType(PolarAreaSeries, 'PolarAreaSeries', PolarLineSeriesBase.$);
    PolarAreaSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarAreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vl:vn', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarAreaSeries;
}(PolarLineSeriesBase));
export { PolarAreaSeries };
/**
 * @hidden
 */
var PolarAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesView, _super);
    function PolarAreaSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c4 = null;
        _this.da = new Path();
        _this.c9 = new Path();
        _this.c8 = new Path();
        _this.c7 = new Path();
        _this.c4 = a;
        return _this;
    }
    PolarAreaSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c4.qh = Defaults.e;
        }
    };
    Object.defineProperty(PolarAreaSeriesView.prototype, "db", {
        get: function () {
            return this.c9;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PolarAreaSeriesView.prototype, "dc", {
        get: function () {
            return this.da;
        },
        enumerable: false,
        configurable: true
    });
    PolarAreaSeriesView.prototype.c5 = function () {
        this.c9.ak = null;
        this.da.ak = null;
        this.c7.ak = null;
        this.c8.ak = null;
        this.aq();
    };
    PolarAreaSeriesView.prototype.c6 = function (a, b) {
        var c = new List$1(Point_$type, 1, a);
        this.c4.u7.d(this.da, c, b);
        this.c4.u7.d(this.c9, c, b);
        this.aq();
    };
    PolarAreaSeriesView.prototype.bb = function () {
        _super.prototype.bb.call(this);
    };
    PolarAreaSeriesView.prototype.bc = function () {
        _super.prototype.bc.call(this);
        var a = this.bo();
        this.c8.ak = this.da.ak;
        this.c7.ak = this.c9.ak;
        this.c8._stroke = a;
        this.c8.ac = this.e.fw + 3;
        this.c7._fill = a;
        this.c7._opacity = 1;
    };
    PolarAreaSeriesView.prototype.a6 = function (a, b) {
        _super.prototype.a6.call(this, a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
                a.s(this.c8);
            }
            else {
                a.s(this.c9);
                a.s(this.da);
            }
        }
    };
    PolarAreaSeriesView.prototype.al = function (a) {
        _super.prototype.al.call(this, a);
        this.e.a8.exportPathData(a, this.da, "polarShape", ["Main"]);
        this.e.a8.exportPathData(a, this.c9, "fillShape", ["Fill"]);
    };
    PolarAreaSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.pf = a;
        this.e.gy = 5;
        this.e.gz = 5;
        this.e.g0 = 5;
    };
    PolarAreaSeriesView.$t = markType(PolarAreaSeriesView, 'PolarAreaSeriesView', PolarLineSeriesBaseView.$);
    return PolarAreaSeriesView;
}(PolarLineSeriesBaseView));
export { PolarAreaSeriesView };
